Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SqlDatabaseReconciler ¶
type SqlDatabaseReconciler struct {
client.Client
Scheme *runtime.Scheme
RefreshRate time.Duration
}
SqlDatabaseReconciler reconciles a SqlDatabase object
func (*SqlDatabaseReconciler) Reconcile ¶
func (r *SqlDatabaseReconciler) Reconcile(ctx context.Context, req ctrl.Request) (ctrl.Result, error)
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.8.3/pkg/reconcile
func (*SqlDatabaseReconciler) SetupWithManager ¶
func (r *SqlDatabaseReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type SqlGrantReconciler ¶
SqlGrantReconciler reconciles a SqlGrant object
func (*SqlGrantReconciler) Reconcile ¶
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.8.3/pkg/reconcile
func (*SqlGrantReconciler) SetupWithManager ¶
func (r *SqlGrantReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type SqlHostReconciler ¶
SqlHostReconciler reconciles a SqlHost object
func (*SqlHostReconciler) Reconcile ¶
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.8.3/pkg/reconcile
func (*SqlHostReconciler) SetupWithManager ¶
func (r *SqlHostReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type SqlUserReconciler ¶
SqlUserReconciler reconciles a SqlUser object
func (*SqlUserReconciler) Reconcile ¶
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state.
func (*SqlUserReconciler) SetupWithManager ¶
func (r *SqlUserReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.